import i18n from 'sveltekit-i18n';
import lang from './lang.json';

/** @type {import('sveltekit-i18n').Config} */
const config = {
  translations: {
    en: { lang },
    pt: { lang },
  },
  loaders: [
    {
      locale: 'en',
      key: 'header',
      loader: async () => (await import('./en/header.json')).default,
    },
    {
      locale: 'pt',
      key: 'header',
      loader: async () => (await import('./pt/header.json')).default,
    },
  ],
};

export const { t, locale, locales, loading, loadTranslations } = new i18n(
  config,
);

// Save to localStorage on change
locale.subscribe(($locale) => {
  if (typeof localStorage !== 'undefined') {
    localStorage.setItem('locale', $locale);
  }
});

// Load from localStorage on initialization
if (typeof localStorage !== 'undefined') {
  const savedLocale = localStorage.getItem('locale');
  if (savedLocale && savedLocale !== 'null') {
    locale.set(savedLocale);
  }
}
